      subroutine dim_reduced(nla,nla1,nd,ntd) ! bernd berg mar 02 2008
c alexei bazavov oct 20 2005. calculate reduced (nd-1) dimensional array.
c nd -- number of dimensions
c nla -- original array with sizes
c ntd -- dimension to exclude
c nla1 -- array with sizes in nd-1 dimensions
      include '../../libs/fortran/implicit.sta'
      include '../../libs/fortran/constants.par'
      dimension nla(nd),nla1(nd-1)
      id1=1
      do id=1,nd
        if(id.ne.ntd) then
          nla1(id1)=nla(id)
          id1=id1+1
        end if
      end do
      return
      end
